<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8" />
<title>{{ event_name }}</title>
<meta name="description" content="">
<link rel="stylesheet" title="default styles" href="http://www.sturm.com.au/shared/base-1.0.css" />
<link rel="icon" href="images/sturm.ico" />
<!--[if lt IE 9]><script src="http://www.sturm.com.au/shared/ie-html5-1.0.js"></script><![endif]-->
<style>
p { margin: 0 0 0.4em; }

body {
  font-family: sans-serif;
  font-size: 81%;
  color: #333;
  width: 700px;
  margin: 1em auto;
}

footer img {
  clear: both;
  display: block;
  margin: 2em 0 0;
}

textarea {
  height: 2.5em;
  width: 15em;
}

.error {
  background: #fcc;
  padding: 0.5em;
}

.booked, .tally {
  color: #999;
}

.booked a {
  color: #999;
  text-decoration: line-through;
}

fieldset {
  background: #eee;
  padding: 1em;
  margin: 2.5em 0 0;
  width: 25em;
}

fieldset h2 { margin-top: 0; }

li a { text-decoration: none; }

#page-summary { font-size: 1.2em; font-style: italic; }

h1#site-title img { margin: 1em 0; }

h1 { margin: 1em 0 0.5em}
</style>
</head>

<body>
<header>
<h1 id="site-title">{{ event_name }}</h1>
<nav>
</nav>
</header>

<section>
{% block main_content %}{% endblock %}
</section>

<footer>
</footer>

</body>
</html>
